pub struct AuthorizationServerPolicyRuleActions {
pub token: Option<TokenAuthorizationServerPolicyRuleAction>,
}Fields
token: Option<TokenAuthorizationServerPolicyRuleAction>Trait Implementations
Sourceimpl Clone for AuthorizationServerPolicyRuleActions
impl Clone for AuthorizationServerPolicyRuleActions
Sourcefn clone(&self) -> AuthorizationServerPolicyRuleActions
fn clone(&self) -> AuthorizationServerPolicyRuleActions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for AuthorizationServerPolicyRuleActions
impl<'de> Deserialize<'de> for AuthorizationServerPolicyRuleActions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AuthorizationServerPolicyRuleActions
impl JsonSchema for AuthorizationServerPolicyRuleActions
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for AuthorizationServerPolicyRuleActions