pub struct CsrMetadata {
pub subject: Option<CsrMetadataSubject>,
pub subject_alt_names: Option<CsrMetadataSubjectAltNames>,
}Fields
subject: Option<CsrMetadataSubject>subject_alt_names: Option<CsrMetadataSubjectAltNames>Trait Implementations
Sourceimpl Clone for CsrMetadata
impl Clone for CsrMetadata
Sourcefn clone(&self) -> CsrMetadata
fn clone(&self) -> CsrMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CsrMetadata
impl Debug for CsrMetadata
Sourceimpl<'de> Deserialize<'de> for CsrMetadata
impl<'de> Deserialize<'de> for CsrMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CsrMetadata
impl JsonSchema for CsrMetadata
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CsrMetadata
impl PartialEq for CsrMetadata
Sourceimpl Serialize for CsrMetadata
impl Serialize for CsrMetadata
impl StructuralPartialEq for CsrMetadata