pub struct InlineHookChannel {
pub config: Option<InlineHookChannelConfig>,
pub type_: Option<EventHookChannelType>,
pub version: String,
}Fields
config: Option<InlineHookChannelConfig>type_: Option<EventHookChannelType>version: StringTrait Implementations
Sourceimpl Clone for InlineHookChannel
impl Clone for InlineHookChannel
Sourcefn clone(&self) -> InlineHookChannel
fn clone(&self) -> InlineHookChannel
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InlineHookChannel
impl Debug for InlineHookChannel
Sourceimpl<'de> Deserialize<'de> for InlineHookChannel
impl<'de> Deserialize<'de> for InlineHookChannel
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for InlineHookChannel
impl JsonSchema for InlineHookChannel
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for InlineHookChannel
impl PartialEq for InlineHookChannel
Sourceimpl Serialize for InlineHookChannel
impl Serialize for InlineHookChannel
impl StructuralPartialEq for InlineHookChannel