pub struct OpenConnectApplication {
pub credentials: Option<OAuthApplicationCredentials>,
pub name: Option<Value>,
pub settings: Option<OpenConnectApplicationSettings>,
}Fields
credentials: Option<OAuthApplicationCredentials>name: Option<Value>settings: Option<OpenConnectApplicationSettings>Trait Implementations
Sourceimpl Clone for OpenConnectApplication
impl Clone for OpenConnectApplication
Sourcefn clone(&self) -> OpenConnectApplication
fn clone(&self) -> OpenConnectApplication
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OpenConnectApplication
impl Debug for OpenConnectApplication
Sourceimpl<'de> Deserialize<'de> for OpenConnectApplication
impl<'de> Deserialize<'de> for OpenConnectApplication
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OpenConnectApplication
impl JsonSchema for OpenConnectApplication
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for OpenConnectApplication
impl PartialEq for OpenConnectApplication
Sourceimpl Serialize for OpenConnectApplication
impl Serialize for OpenConnectApplication
impl StructuralPartialEq for OpenConnectApplication