pub struct PolicyNetworkCondition {
pub connection: Option<Connection>,
pub exclude: Vec<String>,
pub include: Vec<String>,
}Fields
connection: Option<Connection>exclude: Vec<String>include: Vec<String>Trait Implementations
Sourceimpl Clone for PolicyNetworkCondition
impl Clone for PolicyNetworkCondition
Sourcefn clone(&self) -> PolicyNetworkCondition
fn clone(&self) -> PolicyNetworkCondition
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PolicyNetworkCondition
impl Debug for PolicyNetworkCondition
Sourceimpl<'de> Deserialize<'de> for PolicyNetworkCondition
impl<'de> Deserialize<'de> for PolicyNetworkCondition
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PolicyNetworkCondition
impl JsonSchema for PolicyNetworkCondition
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PolicyNetworkCondition
impl PartialEq for PolicyNetworkCondition
Sourceimpl Serialize for PolicyNetworkCondition
impl Serialize for PolicyNetworkCondition
impl StructuralPartialEq for PolicyNetworkCondition