pub struct ProtocolAlgorithmTypeSignature {
pub algorithm: String,
pub scope: Option<Scope>,
}Fields
algorithm: Stringscope: Option<Scope>Trait Implementations
Sourceimpl Clone for ProtocolAlgorithmTypeSignature
impl Clone for ProtocolAlgorithmTypeSignature
Sourcefn clone(&self) -> ProtocolAlgorithmTypeSignature
fn clone(&self) -> ProtocolAlgorithmTypeSignature
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ProtocolAlgorithmTypeSignature
impl<'de> Deserialize<'de> for ProtocolAlgorithmTypeSignature
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProtocolAlgorithmTypeSignature
impl JsonSchema for ProtocolAlgorithmTypeSignature
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ProtocolAlgorithmTypeSignature