pub struct SmsTemplate {
pub created: Option<DateTime<Utc>>,
pub id: String,
pub last_updated: Option<DateTime<Utc>>,
pub name: String,
pub template: String,
pub translations: Option<Links>,
pub type_: Option<SmsTemplateType>,
}Fields
created: Option<DateTime<Utc>>id: Stringlast_updated: Option<DateTime<Utc>>name: Stringtemplate: Stringtranslations: Option<Links>type_: Option<SmsTemplateType>Trait Implementations
Sourceimpl Clone for SmsTemplate
impl Clone for SmsTemplate
Sourcefn clone(&self) -> SmsTemplate
fn clone(&self) -> SmsTemplate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SmsTemplate
impl Debug for SmsTemplate
Sourceimpl<'de> Deserialize<'de> for SmsTemplate
impl<'de> Deserialize<'de> for SmsTemplate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SmsTemplate
impl JsonSchema for SmsTemplate
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SmsTemplate
impl PartialEq for SmsTemplate
Sourceimpl Serialize for SmsTemplate
impl Serialize for SmsTemplate
impl StructuralPartialEq for SmsTemplate