pub struct UserSchemaAttribute {Show 18 fields
pub description: String,
pub enum_: Vec<String>,
pub external_name: String,
pub external_namespace: String,
pub items: Option<UserSchemaAttributeItems>,
pub master: Option<UserSchemaAttributeMaster>,
pub max_length: i64,
pub min_length: i64,
pub mutability: String,
pub one_of: Vec<UserSchemaAttributeEnum>,
pub pattern: String,
pub permissions: Vec<UserSchemaAttributePermission>,
pub required: bool,
pub scope: Option<Links>,
pub title: String,
pub type_: Option<UserSchemaAttributeType>,
pub union: Option<Links>,
pub unique: String,
}Fields
description: Stringenum_: Vec<String>external_name: Stringexternal_namespace: Stringitems: Option<UserSchemaAttributeItems>master: Option<UserSchemaAttributeMaster>max_length: i64min_length: i64mutability: Stringone_of: Vec<UserSchemaAttributeEnum>pattern: Stringpermissions: Vec<UserSchemaAttributePermission>required: boolscope: Option<Links>title: Stringtype_: Option<UserSchemaAttributeType>union: Option<Links>unique: StringTrait Implementations
Sourceimpl Clone for UserSchemaAttribute
impl Clone for UserSchemaAttribute
Sourcefn clone(&self) -> UserSchemaAttribute
fn clone(&self) -> UserSchemaAttribute
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UserSchemaAttribute
impl Debug for UserSchemaAttribute
Sourceimpl<'de> Deserialize<'de> for UserSchemaAttribute
impl<'de> Deserialize<'de> for UserSchemaAttribute
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UserSchemaAttribute
impl JsonSchema for UserSchemaAttribute
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for UserSchemaAttribute
impl PartialEq for UserSchemaAttribute
Sourceimpl Serialize for UserSchemaAttribute
impl Serialize for UserSchemaAttribute
impl StructuralPartialEq for UserSchemaAttribute