pub struct UserSchemaBase {
pub id: String,
pub properties: Option<UserSchemaBaseProperties>,
pub required: Vec<String>,
pub type_: String,
}Fields
id: Stringproperties: Option<UserSchemaBaseProperties>required: Vec<String>type_: StringTrait Implementations
Sourceimpl Clone for UserSchemaBase
impl Clone for UserSchemaBase
Sourcefn clone(&self) -> UserSchemaBase
fn clone(&self) -> UserSchemaBase
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UserSchemaBase
impl Debug for UserSchemaBase
Sourceimpl<'de> Deserialize<'de> for UserSchemaBase
impl<'de> Deserialize<'de> for UserSchemaBase
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UserSchemaBase
impl JsonSchema for UserSchemaBase
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for UserSchemaBase
impl PartialEq for UserSchemaBase
Sourceimpl Serialize for UserSchemaBase
impl Serialize for UserSchemaBase
impl StructuralPartialEq for UserSchemaBase