pub struct UserSchemaBaseProperties {Show 31 fields
pub city: Option<UserSchemaAttribute>,
pub cost_center: Option<UserSchemaAttribute>,
pub country_code: Option<UserSchemaAttribute>,
pub department: Option<UserSchemaAttribute>,
pub display_name: Option<UserSchemaAttribute>,
pub division: Option<UserSchemaAttribute>,
pub email: Option<UserSchemaAttribute>,
pub employee_number: Option<UserSchemaAttribute>,
pub first_name: Option<UserSchemaAttribute>,
pub honorific_prefix: Option<UserSchemaAttribute>,
pub honorific_suffix: Option<UserSchemaAttribute>,
pub last_name: Option<UserSchemaAttribute>,
pub locale: Option<UserSchemaAttribute>,
pub login: Option<UserSchemaAttribute>,
pub manager: Option<UserSchemaAttribute>,
pub manager_id: Option<UserSchemaAttribute>,
pub middle_name: Option<UserSchemaAttribute>,
pub mobile_phone: Option<UserSchemaAttribute>,
pub nick_name: Option<UserSchemaAttribute>,
pub organization: Option<UserSchemaAttribute>,
pub postal_address: Option<UserSchemaAttribute>,
pub preferred_language: Option<UserSchemaAttribute>,
pub primary_phone: Option<UserSchemaAttribute>,
pub profile_url: Option<UserSchemaAttribute>,
pub second_email: Option<UserSchemaAttribute>,
pub state: Option<UserSchemaAttribute>,
pub street_address: Option<UserSchemaAttribute>,
pub timezone: Option<UserSchemaAttribute>,
pub title: Option<UserSchemaAttribute>,
pub user_type: Option<UserSchemaAttribute>,
pub zip_code: Option<UserSchemaAttribute>,
}Fields
city: Option<UserSchemaAttribute>cost_center: Option<UserSchemaAttribute>country_code: Option<UserSchemaAttribute>department: Option<UserSchemaAttribute>display_name: Option<UserSchemaAttribute>division: Option<UserSchemaAttribute>email: Option<UserSchemaAttribute>employee_number: Option<UserSchemaAttribute>first_name: Option<UserSchemaAttribute>honorific_prefix: Option<UserSchemaAttribute>honorific_suffix: Option<UserSchemaAttribute>last_name: Option<UserSchemaAttribute>locale: Option<UserSchemaAttribute>login: Option<UserSchemaAttribute>manager: Option<UserSchemaAttribute>manager_id: Option<UserSchemaAttribute>middle_name: Option<UserSchemaAttribute>mobile_phone: Option<UserSchemaAttribute>nick_name: Option<UserSchemaAttribute>organization: Option<UserSchemaAttribute>postal_address: Option<UserSchemaAttribute>preferred_language: Option<UserSchemaAttribute>primary_phone: Option<UserSchemaAttribute>profile_url: Option<UserSchemaAttribute>second_email: Option<UserSchemaAttribute>state: Option<UserSchemaAttribute>street_address: Option<UserSchemaAttribute>timezone: Option<UserSchemaAttribute>title: Option<UserSchemaAttribute>user_type: Option<UserSchemaAttribute>zip_code: Option<UserSchemaAttribute>Trait Implementations
Sourceimpl Clone for UserSchemaBaseProperties
impl Clone for UserSchemaBaseProperties
Sourcefn clone(&self) -> UserSchemaBaseProperties
fn clone(&self) -> UserSchemaBaseProperties
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UserSchemaBaseProperties
impl Debug for UserSchemaBaseProperties
Sourceimpl<'de> Deserialize<'de> for UserSchemaBaseProperties
impl<'de> Deserialize<'de> for UserSchemaBaseProperties
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UserSchemaBaseProperties
impl JsonSchema for UserSchemaBaseProperties
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for UserSchemaBaseProperties
impl PartialEq for UserSchemaBaseProperties
Sourceimpl Serialize for UserSchemaBaseProperties
impl Serialize for UserSchemaBaseProperties
impl StructuralPartialEq for UserSchemaBaseProperties