pub struct UserSchemaPropertiesProfile {
pub all_of: Vec<UserSchemaPropertiesProfileItem>,
}Fields
all_of: Vec<UserSchemaPropertiesProfileItem>Trait Implementations
Sourceimpl Clone for UserSchemaPropertiesProfile
impl Clone for UserSchemaPropertiesProfile
Sourcefn clone(&self) -> UserSchemaPropertiesProfile
fn clone(&self) -> UserSchemaPropertiesProfile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UserSchemaPropertiesProfile
impl Debug for UserSchemaPropertiesProfile
Sourceimpl<'de> Deserialize<'de> for UserSchemaPropertiesProfile
impl<'de> Deserialize<'de> for UserSchemaPropertiesProfile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UserSchemaPropertiesProfile
impl JsonSchema for UserSchemaPropertiesProfile
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for UserSchemaPropertiesProfile